==> pure-ftpd-1.0.22.tar.bz2: pure-ftpd-1.0.22/src/messages_ru.h <==
#define MSG_TIMEOUT "  "
#define MSG_CAPABILITIES "   (capabilities)"
#define MSG_CLIENT_CLOSED_CNX "  "
#define MSG_CLIENT_READ_ERR "   "
#define MSG_CANT_OPEN_CNX " "
#define MSG_CANT_CREATE_DATA_SOCKET "     "
#define MSG_DEBUG_CLIENT_IS " :"
#define MSG_SYNTAX_ERROR_IP "   IP "
#define MSG_PORT_SUCCESSFUL " PORT  "
#define MSG_ONLY_IPV4V6 "  IPv4  IPv6 (1,2)"
#define MSG_ONLY_IPV4 "  IPv4 (1)"
#define MSG_TIMEOUT_PARSER "   -    "
#define MSG_LINE_TOO_LONG "  "
#define MSG_LOG_OVERFLOW "     "
#define MSG_GOODBYE " .   %llu   %llu ."
#define MSG_DEBUG_COMMAND ""
#define MSG_IS_YOUR_CURRENT_LOCATION " -  "
#define MSG_NOT_LOGGED_IN "       "
#define MSG_AUTH_UNIMPLEMENTED "   (AUTH  ADAT)  "
#define MSG_NO_FILE_NAME "   "
#define MSG_NO_DIRECTORY_NAME "   "
#define MSG_NO_RESTART_POINT "  ,     "
#define MSG_ABOR_SUCCESS " ABOR  "
#define MSG_MISSING_ARG " "
#define MSG_GARBAGE_FOUND "   "
#define MSG_VALUE_TOO_LARGE "   "
#define MSG_IDLE_TIME "    %lu (/)"
#define MSG_SITE_HELP "   SITE"
#define MSG_BAD_CHMOD "  "
#define MSG_UNKNOWN_EXTENSION "-  "
#define MSG_XDBG_OK " XDBG  , debug level   %d"
#define MSG_UNKNOWN_COMMAND " "
#define MSG_TIMEOUT_NOOP "   (    %lu ())"
#define MSG_TIMEOUT_DATA "   (     %lu ())"
#define MSG_SLEEPING "---..."
#define MSG_ALREADY_LOGGED "  "
#define MSG_ANY_PASSWORD "  "
#define MSG_ANONYMOUS_LOGGED "  "
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "     FTP"
#define MSG_USER_OK "   %s  "
#define MSG_CANT_DO_TWICE "     "
#define MSG_UNABLE_SECURE_ANON "    FTP"
#define MSG_BANDWIDTH_RESTRICTED "    "
#define MSG_NO_PASSWORD_NEEDED "  "
#define MSG_NOTRUST "    "
#define MSG_WHOAREYOU " "
#define MSG_AUTH_FAILED "  , "
#define MSG_AUTH_TOOMANY "   "
#define MSG_NO_HOMEDIR "    - "
#define MSG_NO_HOMEDIR2 "%s     "
#define MSG_START_SLASH "  /"
#define MSG_USER_GROUP_ACCESS " %s    "
#define MSG_FXP_SUPPORT "    FXP"
#define MSG_RATIO "    %u:%u (UL/DL)"
#define MSG_CHROOT_FAILED "   chroot()  (jail, sandbox)"
#define MSG_CURRENT_DIR_IS "OK.   %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK.    %s"
#define MSG_IS_NOW_LOGGED_IN "%s "
#define MSG_CANT_CHANGE_DIR "    %s"
#define MSG_PATH_TOO_LONG "  "
#define MSG_CANT_PASV "   PASV  IPv6 .  EPSV."
#define MSG_CANT_PASSIVE "   FTP "
#define MSG_PORTS_BUSY "   TCP "
#define MSG_GETSOCKNAME_DATA "     "
#define MSG_GETPEERNAME "   "
#define MSG_INVALID_IP ",  "
#define MSG_NO_EPSV " IPv6-     EPSV"
#define MSG_BAD_PORT ",           1024"
#define MSG_NO_FXP "    %s (  %s)"
#define MSG_FXP " FXP:  %s  %s"
#define MSG_NO_DATA_CONN "   "
#define MSG_ACCEPT_FAILED "  "
#define MSG_ACCEPT_SUCCESS "   "
#define MSG_CNX_PORT_FAILED "       %d"
#define MSG_CNX_PORT "   %d"
#define MSG_ANON_CANT_MKD ",     "
#define MSG_ANON_CANT_RMD ",     "
#define MSG_ANON_CANT_RENAME "   / "
#define MSG_ANON_CANT_CHANGE_PERMS "     "
#define MSG_GLOB_NO_MEMORY "     %s"
#define MSG_PROBABLY_DENIED "(   \" \")"
#define MSG_GLOB_READ_ERROR "    %s"
#define MSG_GLOB_NO_MATCH "    %s  %s"
#define MSG_CHMOD_FAILED "     %s"
#define MSG_CHMOD_SUCCESS "    %s"
#define MSG_CHMOD_TOTAL_FAILURE ",       "
#define MSG_ANON_CANT_DELETE "    "
#define MSG_ANON_CANT_OVERWRITE "     "
#define MSG_DELE_FAILED "  %s"
#define MSG_DELE_SUCCESS ": %s"
#define MSG_DELE_TOTAL_FAILURE "    "
#define MSG_LOAD_TOO_HIGH \
    "       %3.2f.    \n" \
    "     .  \n" \
    "."
#define MSG_OPEN_FAILURE "  %s"
#define MSG_OPEN_FAILURE2 "   "
#define MSG_STAT_FAILURE "   "
#define MSG_STAT_FAILURE2 "    "
#define MSG_REST_TOO_LARGE_FOR_FILE "  %lld      %lld."
#define MSG_REST_RESET "    0"
#define MSG_NOT_REGULAR_FILE "     "
#define MSG_NOT_MODERATED \
    "     .     \n" \
    "   ."
#define MSG_RATIO_DENIAL \
    ",   /  %u:%u .\n" \
    "  %llu    %llu .   \n" \
    " -    ."
#define MSG_NO_MORE_TO_DOWNLOAD "     "
#define MSG_WINNER " -  .  "
#define MSG_KBYTES_LEFT "%.1f  "
#define MSG_ABORTED " "
#define MSG_DATA_WRITE_FAILED "    "
#define MSG_DATA_READ_FAILED "    "
#define MSG_MMAP_FAILED "    "
#define MSG_WRITE_FAILED "     "
#define MSG_TRANSFER_RATE_M "%.3f  , %.2f /c"
#define MSG_TRANSFER_RATE_K "%.3f  , %.2f /"
#define MSG_TRANSFER_RATE_B "%.3f  , %.2f /c"
#define MSG_SPACE_FREE_M "%.1f   "
#define MSG_SPACE_FREE_K "%f    "
#define MSG_DOWNLOADED " "
#define MSG_REST_NOT_NUMERIC " REST   "
#define MSG_REST_ASCII_STRICT "      ASCII "
#define MSG_REST_ASCII_WORKAROUND "  %lld.    ASCII "
#define MSG_REST_SUCCESS "  %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "  "
#define MSG_SANITY_FILE_FAILURE "  : %s"
#define MSG_MKD_FAILURE "  "
#define MSG_MKD_SUCCESS "   "
#define MSG_RMD_FAILURE "  "
#define MSG_RMD_SUCCESS "   "
#define MSG_TIMESTAMP_FAILURE "   "
#define MSG_MODE_ERROR "  ASCII   "
#define MSG_CREATE_FAILURE "  "
#define MSG_ABRT_ONLY " ABRT     "
#define MSG_UPLOAD_PARTIAL " "
#define MSG_REMOVED ""
#define MSG_UPLOADED ""
#define MSG_GMTIME_FAILURE "   "
#define MSG_TYPE_8BIT_FAILURE "   ,   XXI "
#define MSG_TYPE_UNKNOWN " TYPE"
#define MSG_TYPE_SUCCESS "TYPE "
#define MSG_STRU_FAILURE "  F(ile)"
#define MSG_MODE_FAILURE "   S(tream)"
#define MSG_RENAME_ABORT "   "
#define MSG_RENAME_RNFR_SUCCESS "RNFR ,  ,   "
#define MSG_FILE_DOESNT_EXIST ",     "
#define MSG_RENAME_ALREADY_THERE "   -      "
#define MSG_RENAME_NORNFR "  RNFR  RNTO"
#define MSG_RENAME_FAILURE "  /"
#define MSG_RENAME_SUCCESS "    "
#define MSG_NO_SUPERSERVER "  pure-ftpd  - ( tcpserver)"
#define MSG_NO_FTP_ACCOUNT "   'ftp'"
#define MSG_CONF_ERR "  "
#define MSG_NO_VIRTUAL_FILE "     "
#define MSG_ILLEGAL_THROTTLING "    "
#define MSG_ILLEGAL_TRUSTED_GID "  "
#define MSG_ILLEGAL_USER_LIMIT "    "
#define MSG_ILLEGAL_FACILITY "    syslog"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "   LDAP"
#define MSG_ILLEGAL_LOAD_LIMIT "  "
#define MSG_ILLEGAL_PORTS_RANGE "  "
#define MSG_ILLEGAL_LS_LIMITS "   'ls'"
#define MSG_ILLEGAL_FORCE_PASSIVE " IP   "
#define MSG_ILLEGAL_RATIO "   /"
#define MSG_ILLEGAL_UID_LIMIT "  uid"
#define MSG_ILLEGAL_OPTION " "
#define MSG_LDAP_MISSING_BASE "  LDAPBaseDN    LDAP"
#define MSG_LDAP_WRONG_PARMS "  LDAP"
#define MSG_NEW_CONNECTION "   %s"
#define MSG_WELCOME_TO "  "
#define MSG_MAX_USERS "%lu  ( )  , "
#define MSG_NB_USERS "  %d  %d "
#define MSG_WELCOME_TIME "  %02d:%02d.  : %u."
#define MSG_ANONYMOUS_FTP_ONLY "     "
#define MSG_RATIOS_EVERYONE "    :"
#define MSG_RATIOS_ANONYMOUS "    /:"
#define MSG_RATIOS_RULE "  %u ,  %u ."
#define MSG_INFO_IDLE_M "    %lu  ."
#define MSG_INFO_IDLE_S "    %lu  ."
#define MSG_CANT_READ_FILE ",   [%s]"
#define MSG_LS_TRUNCATED "   %u "
#define MSG_LS_SUCCESS "%u "
#define MSG_LOGOUT "."
#define MSG_AUTH_FAILED_LOG "    [%s]"
#define MSG_ILLEGAL_UMASK "  umask"
#define MSG_STANDALONE_FAILED "  standalone "
#define MSG_NO_ANONYMOUS_LOGIN "   -    "
#define MSG_ANONYMOUS_ANY_PASSWORD "  "
#define MSG_MAX_USERS_IP "   (%lu)   IP"
#define MSG_ACTIVE_DISABLED "  "
#define MSG_TRANSFER_SUCCESSFUL "  "
#define MSG_NO_DISK_SPACE "  -  "
#define MSG_OUT_OF_MEMORY " "
#define MSG_ILLEGAL_TRUSTED_IP "   IP"
#define MSG_NO_ASCII_RESUME " ASCII ,   "
#define MSG_UNKNOWN_ALTLOG "   "
#define MSG_ACCOUNT_DISABLED "   [%s]:  "
#define MSG_SQL_WRONG_PARMS " SQL "
#define MSG_ILLEGAL_CONFIG_FILE_SQL "   SQL"
#define MSG_SQL_MISSING_SERVER "     SQL"
#define MSG_SQL_DOWN "SQL    "
#define MSG_ILLEGAL_QUOTA " "
#define MSG_QUOTA_FILES "%llu   (%d%%) - : %llu "
#define MSG_QUOTA_SIZE "%llu   (%d%%) - : %llu "
#define MSG_QUOTA_EXCEEDED " : %s   "
#define MSG_AUTH_UNKNOWN "  "
#define MSG_PDB_BROKEN "    puredb (   ) -  pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s    %s."
#define MSG_ALIASES_UNKNOWN "  %s."
#define MSG_ALIASES_BROKEN_FILE "  "
#define MSG_ALIASES_LIST "  :"
#define MSG_PERUSER_MAX "    %lu    "
#define MSG_IPV6_OK "  IPv6     "
#define MSG_TLS_INFO "SSL/TLS:  %s  %s, %d-  "
#define MSG_TLS_WEAK "SSL/TLS:  "
#define MSG_TLS_NEEDED ",     .\n" \
     "  ,   SSL/TLS."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"

==> pure-ftpd-1.0.29.tar.bz2: pure-ftpd-1.0.29/src/messages_ru.h <==
#define MSG_TIMEOUT "  "
#define MSG_CAPABILITIES "   (capabilities)"
#define MSG_CLIENT_CLOSED_CNX "  "
#define MSG_CLIENT_READ_ERR "   "
#define MSG_CANT_OPEN_CNX " "
#define MSG_CANT_CREATE_DATA_SOCKET "     "
#define MSG_DEBUG_CLIENT_IS " :"
#define MSG_SYNTAX_ERROR_IP "   IP "
#define MSG_PORT_SUCCESSFUL " PORT  "
#define MSG_ONLY_IPV4V6 "  IPv4  IPv6 (1,2)"
#define MSG_ONLY_IPV4 "  IPv4 (1)"
#define MSG_TIMEOUT_PARSER "   -    "
#define MSG_LINE_TOO_LONG "  "
#define MSG_LOG_OVERFLOW "     "
#define MSG_GOODBYE " .   %llu   %llu ."
#define MSG_DEBUG_COMMAND ""
#define MSG_IS_YOUR_CURRENT_LOCATION " -  "
#define MSG_NOT_LOGGED_IN "       "
#define MSG_AUTH_UNIMPLEMENTED "   (AUTH  ADAT)  "
#define MSG_NO_FILE_NAME "   "
#define MSG_NO_DIRECTORY_NAME "   "
#define MSG_NO_RESTART_POINT "  ,     "
#define MSG_ABOR_SUCCESS " ABOR  "
#define MSG_MISSING_ARG " "
#define MSG_GARBAGE_FOUND "   "
#define MSG_VALUE_TOO_LARGE "   "
#define MSG_IDLE_TIME "    %lu (/)"
#define MSG_SITE_HELP "   SITE"
#define MSG_BAD_CHMOD "  "
#define MSG_UNKNOWN_EXTENSION "-  "
#define MSG_XDBG_OK " XDBG  , debug level   %d"
#define MSG_UNKNOWN_COMMAND " "
#define MSG_TIMEOUT_NOOP "   (    %lu ())"
#define MSG_TIMEOUT_DATA "   (     %lu ())"
#define MSG_SLEEPING "---..."
#define MSG_ALREADY_LOGGED "  "
#define MSG_ANY_PASSWORD "  "
#define MSG_ANONYMOUS_LOGGED "  "
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "     FTP"
#define MSG_USER_OK "   %s  "
#define MSG_CANT_DO_TWICE "     "
#define MSG_UNABLE_SECURE_ANON "    FTP"
#define MSG_BANDWIDTH_RESTRICTED "    "
#define MSG_NO_PASSWORD_NEEDED "  "
#define MSG_NOTRUST "    "
#define MSG_WHOAREYOU " "
#define MSG_AUTH_FAILED "  , "
#define MSG_AUTH_TOOMANY "   "
#define MSG_NO_HOMEDIR "    - "
#define MSG_NO_HOMEDIR2 "%s     "
#define MSG_START_SLASH "  /"
#define MSG_USER_GROUP_ACCESS " %s    "
#define MSG_FXP_SUPPORT "    FXP"
#define MSG_RATIO "    %u:%u (UL/DL)"
#define MSG_CHROOT_FAILED "   chroot()  (jail, sandbox)"
#define MSG_CURRENT_DIR_IS "OK.   %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK.    %s"
#define MSG_IS_NOW_LOGGED_IN "%s "
#define MSG_CANT_CHANGE_DIR "    %s"
#define MSG_PATH_TOO_LONG "  "
#define MSG_CANT_PASV "   PASV  IPv6 .  EPSV."
#define MSG_CANT_PASSIVE "   FTP "
#define MSG_PORTS_BUSY "   TCP "
#define MSG_GETSOCKNAME_DATA "     "
#define MSG_GETPEERNAME "   "
#define MSG_INVALID_IP ",  "
#define MSG_NO_EPSV " IPv6-     EPSV"
#define MSG_BAD_PORT ",           1024"
#define MSG_NO_FXP "    %s (  %s)"
#define MSG_FXP " FXP:  %s  %s"
#define MSG_NO_DATA_CONN "   "
#define MSG_ACCEPT_FAILED "  "
#define MSG_ACCEPT_SUCCESS "   "
#define MSG_CNX_PORT_FAILED "       %d"
#define MSG_CNX_PORT "   %d"
#define MSG_ANON_CANT_MKD ",     "
#define MSG_ANON_CANT_RMD ",     "
#define MSG_ANON_CANT_RENAME "   / "
#define MSG_ANON_CANT_CHANGE_PERMS "     "
#define MSG_GLOB_NO_MEMORY "     %s"
#define MSG_PROBABLY_DENIED "(   \" \")"
#define MSG_GLOB_READ_ERROR "    %s"
#define MSG_GLOB_NO_MATCH "    %s  %s"
#define MSG_CHMOD_FAILED "     %s"
#define MSG_CHMOD_SUCCESS "    %s"
#define MSG_CHMOD_TOTAL_FAILURE ",       "
#define MSG_ANON_CANT_DELETE "    "
#define MSG_ANON_CANT_OVERWRITE "     "
#define MSG_DELE_FAILED "  %s"
#define MSG_DELE_SUCCESS ": %s%s%s%s"
#define MSG_DELE_TOTAL_FAILURE "    "
#define MSG_LOAD_TOO_HIGH \
    "       %3.2f.    \n" \
    "     .  \n" \
    "."
#define MSG_OPEN_FAILURE "  %s"
#define MSG_OPEN_FAILURE2 "   "
#define MSG_STAT_FAILURE "   "
#define MSG_STAT_FAILURE2 "    "
#define MSG_REST_TOO_LARGE_FOR_FILE "  %lld      %lld."
#define MSG_REST_RESET "    0"
#define MSG_NOT_REGULAR_FILE "     "
#define MSG_NOT_MODERATED \
    "     .     \n" \
    "   ."
#define MSG_RATIO_DENIAL \
    ",   /  %u:%u .\n" \
    "  %llu    %llu .   \n" \
    " -    ."
#define MSG_NO_MORE_TO_DOWNLOAD "     "
#define MSG_WINNER " -  .  "
#define MSG_KBYTES_LEFT "%.1f  "
#define MSG_ABORTED " "
#define MSG_DATA_WRITE_FAILED "    "
#define MSG_DATA_READ_FAILED "    "
#define MSG_MMAP_FAILED "    "
#define MSG_WRITE_FAILED "     "
#define MSG_TRANSFER_RATE_M "%.3f  , %.2f /c"
#define MSG_TRANSFER_RATE_K "%.3f  , %.2f /"
#define MSG_TRANSFER_RATE_B "%.3f  , %.2f /c"
#define MSG_SPACE_FREE_M "%.1f   "
#define MSG_SPACE_FREE_K "%f    "
#define MSG_DOWNLOADED " "
#define MSG_REST_NOT_NUMERIC " REST   "
#define MSG_REST_ASCII_STRICT "      ASCII "
#define MSG_REST_ASCII_WORKAROUND "  %lld.    ASCII "
#define MSG_REST_SUCCESS "  %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "  "
#define MSG_SANITY_FILE_FAILURE "  : %s"
#define MSG_MKD_FAILURE "  "
#define MSG_MKD_SUCCESS "   "
#define MSG_RMD_FAILURE "  "
#define MSG_RMD_SUCCESS "   "
#define MSG_TIMESTAMP_FAILURE "   "
#define MSG_MODE_ERROR "  ASCII   "
#define MSG_CREATE_FAILURE "  "
#define MSG_ABRT_ONLY " ABRT     "
#define MSG_UPLOAD_PARTIAL " "
#define MSG_REMOVED ""
#define MSG_UPLOADED ""
#define MSG_GMTIME_FAILURE "   "
#define MSG_TYPE_8BIT_FAILURE "   ,   XXI "
#define MSG_TYPE_UNKNOWN " TYPE"
#define MSG_TYPE_SUCCESS "TYPE "
#define MSG_STRU_FAILURE "  F(ile)"
#define MSG_MODE_FAILURE "   S(tream)"
#define MSG_RENAME_ABORT "   "
#define MSG_RENAME_RNFR_SUCCESS "RNFR ,  ,   "
#define MSG_FILE_DOESNT_EXIST ",     "
#define MSG_RENAME_ALREADY_THERE "   -      "
#define MSG_RENAME_NORNFR "  RNFR  RNTO"
#define MSG_RENAME_FAILURE "  /"
#define MSG_RENAME_SUCCESS "    "
#define MSG_NO_SUPERSERVER "  pure-ftpd  - ( tcpserver)"
#define MSG_NO_FTP_ACCOUNT "   'ftp'"
#define MSG_CONF_ERR "  "
#define MSG_NO_VIRTUAL_FILE "     "
#define MSG_ILLEGAL_THROTTLING "    "
#define MSG_ILLEGAL_TRUSTED_GID "  "
#define MSG_ILLEGAL_USER_LIMIT "    "
#define MSG_ILLEGAL_FACILITY "    syslog"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "   LDAP"
#define MSG_ILLEGAL_LOAD_LIMIT "  "
#define MSG_ILLEGAL_PORTS_RANGE "  "
#define MSG_ILLEGAL_LS_LIMITS "   'ls'"
#define MSG_ILLEGAL_FORCE_PASSIVE " IP   "
#define MSG_ILLEGAL_RATIO "   /"
#define MSG_ILLEGAL_UID_LIMIT "  uid"
#define MSG_ILLEGAL_OPTION " "
#define MSG_LDAP_MISSING_BASE "  LDAPBaseDN    LDAP"
#define MSG_LDAP_WRONG_PARMS "  LDAP"
#define MSG_NEW_CONNECTION "   %s"
#define MSG_WELCOME_TO "  "
#define MSG_MAX_USERS "%lu  ( )  , "
#define MSG_NB_USERS "  %d  %d "
#define MSG_WELCOME_TIME "  %02d:%02d.  : %u."
#define MSG_ANONYMOUS_FTP_ONLY "     "
#define MSG_RATIOS_EVERYONE "    :"
#define MSG_RATIOS_ANONYMOUS "    /:"
#define MSG_RATIOS_RULE "  %u ,  %u ."
#define MSG_INFO_IDLE_M "    %lu  ."
#define MSG_INFO_IDLE_S "    %lu  ."
#define MSG_CANT_READ_FILE ",   [%s]"
#define MSG_LS_TRUNCATED "   %u "
#define MSG_LS_SUCCESS "%u "
#define MSG_LOGOUT "."
#define MSG_AUTH_FAILED_LOG "    [%s]"
#define MSG_ILLEGAL_UMASK "  umask"
#define MSG_STANDALONE_FAILED "  standalone "
#define MSG_NO_ANONYMOUS_LOGIN "   -    "
#define MSG_ANONYMOUS_ANY_PASSWORD "  "
#define MSG_MAX_USERS_IP "   (%lu)   IP"
#define MSG_ACTIVE_DISABLED "  "
#define MSG_TRANSFER_SUCCESSFUL "  "
#define MSG_NO_DISK_SPACE "  -  "
#define MSG_OUT_OF_MEMORY " "
#define MSG_ILLEGAL_TRUSTED_IP "   IP"
#define MSG_NO_ASCII_RESUME " ASCII ,   "
#define MSG_UNKNOWN_ALTLOG "   "
#define MSG_ACCOUNT_DISABLED "   [%s]:  "
#define MSG_SQL_WRONG_PARMS " SQL "
#define MSG_ILLEGAL_CONFIG_FILE_SQL "   SQL"
#define MSG_SQL_MISSING_SERVER "     SQL"
#define MSG_SQL_DOWN "SQL    "
#define MSG_ILLEGAL_QUOTA " "
#define MSG_QUOTA_FILES "%llu   (%d%%) - : %llu "
#define MSG_QUOTA_SIZE "%llu   (%d%%) - : %llu "
#define MSG_QUOTA_EXCEEDED " : [%s]   "
#define MSG_AUTH_UNKNOWN "  "
#define MSG_PDB_BROKEN "    puredb (   ) -  pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s    %s."
#define MSG_ALIASES_UNKNOWN "  %s."
#define MSG_ALIASES_BROKEN_FILE "  "
#define MSG_ALIASES_LIST "  :"
#define MSG_PERUSER_MAX "    %lu    "
#define MSG_IPV6_OK "  IPv6     "
#define MSG_TLS_INFO "SSL/TLS:  %s  %s, %d-  "
#define MSG_TLS_WEAK "SSL/TLS:  "
#define MSG_TLS_NEEDED ",     .\n" \
     "  ,   SSL/TLS."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
